import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { WorkMailServiceException as __BaseException } from "./WorkMailServiceException";
export declare const AccessControlRuleEffect: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type AccessControlRuleEffect =
  (typeof AccessControlRuleEffect)[keyof typeof AccessControlRuleEffect];
export interface AccessControlRule {
  Name?: string;
  Effect?: AccessControlRuleEffect;
  Description?: string;
  IpRanges?: string[];
  NotIpRanges?: string[];
  Actions?: string[];
  NotActions?: string[];
  UserIds?: string[];
  NotUserIds?: string[];
  DateCreated?: Date;
  DateModified?: Date;
  ImpersonationRoleIds?: string[];
  NotImpersonationRoleIds?: string[];
}
export declare const AccessEffect: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type AccessEffect = (typeof AccessEffect)[keyof typeof AccessEffect];
export interface AssociateDelegateToResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  EntityId: string | undefined;
}
export interface AssociateDelegateToResourceResponse {}
export declare class EntityNotFoundException extends __BaseException {
  readonly name: "EntityNotFoundException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<EntityNotFoundException, __BaseException>
  );
}
export declare class EntityStateException extends __BaseException {
  readonly name: "EntityStateException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<EntityStateException, __BaseException>
  );
}
export declare class InvalidParameterException extends __BaseException {
  readonly name: "InvalidParameterException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidParameterException, __BaseException>
  );
}
export declare class OrganizationNotFoundException extends __BaseException {
  readonly name: "OrganizationNotFoundException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<OrganizationNotFoundException, __BaseException>
  );
}
export declare class OrganizationStateException extends __BaseException {
  readonly name: "OrganizationStateException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<OrganizationStateException, __BaseException>
  );
}
export declare class UnsupportedOperationException extends __BaseException {
  readonly name: "UnsupportedOperationException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<UnsupportedOperationException, __BaseException>
  );
}
export interface AssociateMemberToGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  MemberId: string | undefined;
}
export interface AssociateMemberToGroupResponse {}
export declare class DirectoryServiceAuthenticationFailedException extends __BaseException {
  readonly name: "DirectoryServiceAuthenticationFailedException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      DirectoryServiceAuthenticationFailedException,
      __BaseException
    >
  );
}
export declare class DirectoryUnavailableException extends __BaseException {
  readonly name: "DirectoryUnavailableException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<DirectoryUnavailableException, __BaseException>
  );
}
export interface AssumeImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
}
export interface AssumeImpersonationRoleResponse {
  Token?: string;
  ExpiresIn?: number;
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface RedactedEwsAvailabilityProvider {
  EwsEndpoint?: string;
  EwsUsername?: string;
}
export interface LambdaAvailabilityProvider {
  LambdaArn: string | undefined;
}
export declare const AvailabilityProviderType: {
  readonly EWS: "EWS";
  readonly LAMBDA: "LAMBDA";
};
export type AvailabilityProviderType =
  (typeof AvailabilityProviderType)[keyof typeof AvailabilityProviderType];
export interface AvailabilityConfiguration {
  DomainName?: string;
  ProviderType?: AvailabilityProviderType;
  EwsProvider?: RedactedEwsAvailabilityProvider;
  LambdaProvider?: LambdaAvailabilityProvider;
  DateCreated?: Date;
  DateModified?: Date;
}
export interface BookingOptions {
  AutoAcceptRequests?: boolean;
  AutoDeclineRecurringRequests?: boolean;
  AutoDeclineConflictingRequests?: boolean;
}
export interface CancelMailboxExportJobRequest {
  ClientToken?: string;
  JobId: string | undefined;
  OrganizationId: string | undefined;
}
export interface CancelMailboxExportJobResponse {}
export interface CreateAliasRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Alias: string | undefined;
}
export interface CreateAliasResponse {}
export declare class EmailAddressInUseException extends __BaseException {
  readonly name: "EmailAddressInUseException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<EmailAddressInUseException, __BaseException>
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class MailDomainNotFoundException extends __BaseException {
  readonly name: "MailDomainNotFoundException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<MailDomainNotFoundException, __BaseException>
  );
}
export declare class MailDomainStateException extends __BaseException {
  readonly name: "MailDomainStateException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<MailDomainStateException, __BaseException>
  );
}
export interface EwsAvailabilityProvider {
  EwsEndpoint: string | undefined;
  EwsUsername: string | undefined;
  EwsPassword: string | undefined;
}
export interface CreateAvailabilityConfigurationRequest {
  ClientToken?: string;
  OrganizationId: string | undefined;
  DomainName: string | undefined;
  EwsProvider?: EwsAvailabilityProvider;
  LambdaProvider?: LambdaAvailabilityProvider;
}
export interface CreateAvailabilityConfigurationResponse {}
export declare class NameAvailabilityException extends __BaseException {
  readonly name: "NameAvailabilityException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<NameAvailabilityException, __BaseException>
  );
}
export interface CreateGroupRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
  HiddenFromGlobalAddressList?: boolean;
}
export interface CreateGroupResponse {
  GroupId?: string;
}
export declare class ReservedNameException extends __BaseException {
  readonly name: "ReservedNameException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<ReservedNameException, __BaseException>
  );
}
export interface ImpersonationRule {
  ImpersonationRuleId: string | undefined;
  Name?: string;
  Description?: string;
  Effect: AccessEffect | undefined;
  TargetUsers?: string[];
  NotTargetUsers?: string[];
}
export declare const ImpersonationRoleType: {
  readonly FULL_ACCESS: "FULL_ACCESS";
  readonly READ_ONLY: "READ_ONLY";
};
export type ImpersonationRoleType =
  (typeof ImpersonationRoleType)[keyof typeof ImpersonationRoleType];
export interface CreateImpersonationRoleRequest {
  ClientToken?: string;
  OrganizationId: string | undefined;
  Name: string | undefined;
  Type: ImpersonationRoleType | undefined;
  Description?: string;
  Rules: ImpersonationRule[] | undefined;
}
export interface CreateImpersonationRoleResponse {
  ImpersonationRoleId?: string;
}
export declare const MobileDeviceAccessRuleEffect: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type MobileDeviceAccessRuleEffect =
  (typeof MobileDeviceAccessRuleEffect)[keyof typeof MobileDeviceAccessRuleEffect];
export interface CreateMobileDeviceAccessRuleRequest {
  OrganizationId: string | undefined;
  ClientToken?: string;
  Name: string | undefined;
  Description?: string;
  Effect: MobileDeviceAccessRuleEffect | undefined;
  DeviceTypes?: string[];
  NotDeviceTypes?: string[];
  DeviceModels?: string[];
  NotDeviceModels?: string[];
  DeviceOperatingSystems?: string[];
  NotDeviceOperatingSystems?: string[];
  DeviceUserAgents?: string[];
  NotDeviceUserAgents?: string[];
}
export interface CreateMobileDeviceAccessRuleResponse {
  MobileDeviceAccessRuleId?: string;
}
export interface Domain {
  DomainName: string | undefined;
  HostedZoneId?: string;
}
export interface CreateOrganizationRequest {
  DirectoryId?: string;
  Alias: string | undefined;
  ClientToken?: string;
  Domains?: Domain[];
  KmsKeyArn?: string;
  EnableInteroperability?: boolean;
}
export interface CreateOrganizationResponse {
  OrganizationId?: string;
}
export declare class DirectoryInUseException extends __BaseException {
  readonly name: "DirectoryInUseException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<DirectoryInUseException, __BaseException>
  );
}
export declare const ResourceType: {
  readonly EQUIPMENT: "EQUIPMENT";
  readonly ROOM: "ROOM";
};
export type ResourceType = (typeof ResourceType)[keyof typeof ResourceType];
export interface CreateResourceRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
  Type: ResourceType | undefined;
  Description?: string;
  HiddenFromGlobalAddressList?: boolean;
}
export interface CreateResourceResponse {
  ResourceId?: string;
}
export declare const UserRole: {
  readonly REMOTE_USER: "REMOTE_USER";
  readonly RESOURCE: "RESOURCE";
  readonly SYSTEM_USER: "SYSTEM_USER";
  readonly USER: "USER";
};
export type UserRole = (typeof UserRole)[keyof typeof UserRole];
export interface CreateUserRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
  DisplayName: string | undefined;
  Password?: string;
  Role?: UserRole;
  FirstName?: string;
  LastName?: string;
  HiddenFromGlobalAddressList?: boolean;
}
export interface CreateUserResponse {
  UserId?: string;
}
export declare class InvalidPasswordException extends __BaseException {
  readonly name: "InvalidPasswordException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidPasswordException, __BaseException>
  );
}
export declare const MemberType: {
  readonly GROUP: "GROUP";
  readonly USER: "USER";
};
export type MemberType = (typeof MemberType)[keyof typeof MemberType];
export interface Delegate {
  Id: string | undefined;
  Type: MemberType | undefined;
}
export interface DeleteAccessControlRuleRequest {
  OrganizationId: string | undefined;
  Name: string | undefined;
}
export interface DeleteAccessControlRuleResponse {}
export interface DeleteAliasRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Alias: string | undefined;
}
export interface DeleteAliasResponse {}
export interface DeleteAvailabilityConfigurationRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface DeleteAvailabilityConfigurationResponse {}
export interface DeleteEmailMonitoringConfigurationRequest {
  OrganizationId: string | undefined;
}
export interface DeleteEmailMonitoringConfigurationResponse {}
export interface DeleteGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
}
export interface DeleteGroupResponse {}
export interface DeleteImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
}
export interface DeleteImpersonationRoleResponse {}
export interface DeleteMailboxPermissionsRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  GranteeId: string | undefined;
}
export interface DeleteMailboxPermissionsResponse {}
export interface DeleteMobileDeviceAccessOverrideRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  DeviceId: string | undefined;
}
export interface DeleteMobileDeviceAccessOverrideResponse {}
export interface DeleteMobileDeviceAccessRuleRequest {
  OrganizationId: string | undefined;
  MobileDeviceAccessRuleId: string | undefined;
}
export interface DeleteMobileDeviceAccessRuleResponse {}
export interface DeleteOrganizationRequest {
  ClientToken?: string;
  OrganizationId: string | undefined;
  DeleteDirectory: boolean | undefined;
  ForceDelete?: boolean;
}
export interface DeleteOrganizationResponse {
  OrganizationId?: string;
  State?: string;
}
export interface DeleteResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
}
export interface DeleteResourceResponse {}
export interface DeleteRetentionPolicyRequest {
  OrganizationId: string | undefined;
  Id: string | undefined;
}
export interface DeleteRetentionPolicyResponse {}
export interface DeleteUserRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
}
export interface DeleteUserResponse {}
export interface DeregisterFromWorkMailRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
}
export interface DeregisterFromWorkMailResponse {}
export interface DeregisterMailDomainRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface DeregisterMailDomainResponse {}
export declare class InvalidCustomSesConfigurationException extends __BaseException {
  readonly name: "InvalidCustomSesConfigurationException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      InvalidCustomSesConfigurationException,
      __BaseException
    >
  );
}
export declare class MailDomainInUseException extends __BaseException {
  readonly name: "MailDomainInUseException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<MailDomainInUseException, __BaseException>
  );
}
export interface DescribeEmailMonitoringConfigurationRequest {
  OrganizationId: string | undefined;
}
export interface DescribeEmailMonitoringConfigurationResponse {
  RoleArn?: string;
  LogGroupArn?: string;
}
export interface DescribeEntityRequest {
  OrganizationId: string | undefined;
  Email: string | undefined;
}
export declare const EntityType: {
  readonly GROUP: "GROUP";
  readonly RESOURCE: "RESOURCE";
  readonly USER: "USER";
};
export type EntityType = (typeof EntityType)[keyof typeof EntityType];
export interface DescribeEntityResponse {
  EntityId?: string;
  Name?: string;
  Type?: EntityType;
}
export interface DescribeGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
}
export declare const EntityState: {
  readonly DELETED: "DELETED";
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type EntityState = (typeof EntityState)[keyof typeof EntityState];
export interface DescribeGroupResponse {
  GroupId?: string;
  Name?: string;
  Email?: string;
  State?: EntityState;
  EnabledDate?: Date;
  DisabledDate?: Date;
  HiddenFromGlobalAddressList?: boolean;
}
export interface DescribeInboundDmarcSettingsRequest {
  OrganizationId: string | undefined;
}
export interface DescribeInboundDmarcSettingsResponse {
  Enforced?: boolean;
}
export interface DescribeMailboxExportJobRequest {
  JobId: string | undefined;
  OrganizationId: string | undefined;
}
export declare const MailboxExportJobState: {
  readonly CANCELLED: "CANCELLED";
  readonly COMPLETED: "COMPLETED";
  readonly FAILED: "FAILED";
  readonly RUNNING: "RUNNING";
};
export type MailboxExportJobState =
  (typeof MailboxExportJobState)[keyof typeof MailboxExportJobState];
export interface DescribeMailboxExportJobResponse {
  EntityId?: string;
  Description?: string;
  RoleArn?: string;
  KmsKeyArn?: string;
  S3BucketName?: string;
  S3Prefix?: string;
  S3Path?: string;
  EstimatedProgress?: number;
  State?: MailboxExportJobState;
  ErrorInfo?: string;
  StartTime?: Date;
  EndTime?: Date;
}
export interface DescribeOrganizationRequest {
  OrganizationId: string | undefined;
}
export interface DescribeOrganizationResponse {
  OrganizationId?: string;
  Alias?: string;
  State?: string;
  DirectoryId?: string;
  DirectoryType?: string;
  DefaultMailDomain?: string;
  CompletedDate?: Date;
  ErrorMessage?: string;
  ARN?: string;
  MigrationAdmin?: string;
  InteroperabilityEnabled?: boolean;
}
export interface DescribeResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
}
export interface DescribeResourceResponse {
  ResourceId?: string;
  Email?: string;
  Name?: string;
  Type?: ResourceType;
  BookingOptions?: BookingOptions;
  State?: EntityState;
  EnabledDate?: Date;
  DisabledDate?: Date;
  Description?: string;
  HiddenFromGlobalAddressList?: boolean;
}
export interface DescribeUserRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
}
export interface DescribeUserResponse {
  UserId?: string;
  Name?: string;
  Email?: string;
  DisplayName?: string;
  State?: EntityState;
  UserRole?: UserRole;
  EnabledDate?: Date;
  DisabledDate?: Date;
  MailboxProvisionedDate?: Date;
  MailboxDeprovisionedDate?: Date;
  FirstName?: string;
  LastName?: string;
  HiddenFromGlobalAddressList?: boolean;
  Initials?: string;
  Telephone?: string;
  Street?: string;
  JobTitle?: string;
  City?: string;
  Company?: string;
  ZipCode?: string;
  Department?: string;
  Country?: string;
  Office?: string;
}
export interface DisassociateDelegateFromResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  EntityId: string | undefined;
}
export interface DisassociateDelegateFromResourceResponse {}
export interface DisassociateMemberFromGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  MemberId: string | undefined;
}
export interface DisassociateMemberFromGroupResponse {}
export interface DnsRecord {
  Type?: string;
  Hostname?: string;
  Value?: string;
}
export declare const DnsRecordVerificationStatus: {
  readonly FAILED: "FAILED";
  readonly PENDING: "PENDING";
  readonly VERIFIED: "VERIFIED";
};
export type DnsRecordVerificationStatus =
  (typeof DnsRecordVerificationStatus)[keyof typeof DnsRecordVerificationStatus];
export declare class EntityAlreadyRegisteredException extends __BaseException {
  readonly name: "EntityAlreadyRegisteredException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      EntityAlreadyRegisteredException,
      __BaseException
    >
  );
}
export declare const RetentionAction: {
  readonly DELETE: "DELETE";
  readonly NONE: "NONE";
  readonly PERMANENTLY_DELETE: "PERMANENTLY_DELETE";
};
export type RetentionAction =
  (typeof RetentionAction)[keyof typeof RetentionAction];
export declare const FolderName: {
  readonly DELETED_ITEMS: "DELETED_ITEMS";
  readonly DRAFTS: "DRAFTS";
  readonly INBOX: "INBOX";
  readonly JUNK_EMAIL: "JUNK_EMAIL";
  readonly SENT_ITEMS: "SENT_ITEMS";
};
export type FolderName = (typeof FolderName)[keyof typeof FolderName];
export interface FolderConfiguration {
  Name: FolderName | undefined;
  Action: RetentionAction | undefined;
  Period?: number;
}
export interface GetAccessControlEffectRequest {
  OrganizationId: string | undefined;
  IpAddress: string | undefined;
  Action: string | undefined;
  UserId?: string;
  ImpersonationRoleId?: string;
}
export interface GetAccessControlEffectResponse {
  Effect?: AccessControlRuleEffect;
  MatchedRules?: string[];
}
export interface GetDefaultRetentionPolicyRequest {
  OrganizationId: string | undefined;
}
export interface GetDefaultRetentionPolicyResponse {
  Id?: string;
  Name?: string;
  Description?: string;
  FolderConfigurations?: FolderConfiguration[];
}
export interface GetImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
}
export interface GetImpersonationRoleResponse {
  ImpersonationRoleId?: string;
  Name?: string;
  Type?: ImpersonationRoleType;
  Description?: string;
  Rules?: ImpersonationRule[];
  DateCreated?: Date;
  DateModified?: Date;
}
export interface GetImpersonationRoleEffectRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
  TargetUser: string | undefined;
}
export interface ImpersonationMatchedRule {
  ImpersonationRuleId?: string;
  Name?: string;
}
export interface GetImpersonationRoleEffectResponse {
  Type?: ImpersonationRoleType;
  Effect?: AccessEffect;
  MatchedRules?: ImpersonationMatchedRule[];
}
export interface GetMailboxDetailsRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
}
export interface GetMailboxDetailsResponse {
  MailboxQuota?: number;
  MailboxSize?: number;
}
export interface GetMailDomainRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface GetMailDomainResponse {
  Records?: DnsRecord[];
  IsTestDomain?: boolean;
  IsDefault?: boolean;
  OwnershipVerificationStatus?: DnsRecordVerificationStatus;
  DkimVerificationStatus?: DnsRecordVerificationStatus;
}
export interface GetMobileDeviceAccessEffectRequest {
  OrganizationId: string | undefined;
  DeviceType?: string;
  DeviceModel?: string;
  DeviceOperatingSystem?: string;
  DeviceUserAgent?: string;
}
export interface MobileDeviceAccessMatchedRule {
  MobileDeviceAccessRuleId?: string;
  Name?: string;
}
export interface GetMobileDeviceAccessEffectResponse {
  Effect?: MobileDeviceAccessRuleEffect;
  MatchedRules?: MobileDeviceAccessMatchedRule[];
}
export interface GetMobileDeviceAccessOverrideRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  DeviceId: string | undefined;
}
export interface GetMobileDeviceAccessOverrideResponse {
  UserId?: string;
  DeviceId?: string;
  Effect?: MobileDeviceAccessRuleEffect;
  Description?: string;
  DateCreated?: Date;
  DateModified?: Date;
}
export interface Group {
  Id?: string;
  Email?: string;
  Name?: string;
  State?: EntityState;
  EnabledDate?: Date;
  DisabledDate?: Date;
}
export interface GroupIdentifier {
  GroupId?: string;
  GroupName?: string;
}
export interface ImpersonationRole {
  ImpersonationRoleId?: string;
  Name?: string;
  Type?: ImpersonationRoleType;
  DateCreated?: Date;
  DateModified?: Date;
}
export declare class InvalidConfigurationException extends __BaseException {
  readonly name: "InvalidConfigurationException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidConfigurationException, __BaseException>
  );
}
export interface MailboxExportJob {
  JobId?: string;
  EntityId?: string;
  Description?: string;
  S3BucketName?: string;
  S3Path?: string;
  EstimatedProgress?: number;
  State?: MailboxExportJobState;
  StartTime?: Date;
  EndTime?: Date;
}
export interface ListAccessControlRulesRequest {
  OrganizationId: string | undefined;
}
export interface ListAccessControlRulesResponse {
  Rules?: AccessControlRule[];
}
export interface ListAliasesRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListAliasesResponse {
  Aliases?: string[];
  NextToken?: string;
}
export interface ListAvailabilityConfigurationsRequest {
  OrganizationId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface ListAvailabilityConfigurationsResponse {
  AvailabilityConfigurations?: AvailabilityConfiguration[];
  NextToken?: string;
}
export interface ListGroupMembersRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface Member {
  Id?: string;
  Name?: string;
  Type?: MemberType;
  State?: EntityState;
  EnabledDate?: Date;
  DisabledDate?: Date;
}
export interface ListGroupMembersResponse {
  Members?: Member[];
  NextToken?: string;
}
export interface ListGroupsFilters {
  NamePrefix?: string;
  PrimaryEmailPrefix?: string;
  State?: EntityState;
}
export interface ListGroupsRequest {
  OrganizationId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
  Filters?: ListGroupsFilters;
}
export interface ListGroupsResponse {
  Groups?: Group[];
  NextToken?: string;
}
export interface ListGroupsForEntityFilters {
  GroupNamePrefix?: string;
}
export interface ListGroupsForEntityRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Filters?: ListGroupsForEntityFilters;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListGroupsForEntityResponse {
  Groups?: GroupIdentifier[];
  NextToken?: string;
}
export interface ListImpersonationRolesRequest {
  OrganizationId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListImpersonationRolesResponse {
  Roles?: ImpersonationRole[];
  NextToken?: string;
}
export interface ListMailboxExportJobsRequest {
  OrganizationId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListMailboxExportJobsResponse {
  Jobs?: MailboxExportJob[];
  NextToken?: string;
}
export interface ListMailboxPermissionsRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export declare const PermissionType: {
  readonly FULL_ACCESS: "FULL_ACCESS";
  readonly SEND_AS: "SEND_AS";
  readonly SEND_ON_BEHALF: "SEND_ON_BEHALF";
};
export type PermissionType =
  (typeof PermissionType)[keyof typeof PermissionType];
export interface Permission {
  GranteeId: string | undefined;
  GranteeType: MemberType | undefined;
  PermissionValues: PermissionType[] | undefined;
}
export interface ListMailboxPermissionsResponse {
  Permissions?: Permission[];
  NextToken?: string;
}
export interface ListMailDomainsRequest {
  OrganizationId: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface MailDomainSummary {
  DomainName?: string;
  DefaultDomain?: boolean;
}
export interface ListMailDomainsResponse {
  MailDomains?: MailDomainSummary[];
  NextToken?: string;
}
export interface ListMobileDeviceAccessOverridesRequest {
  OrganizationId: string | undefined;
  UserId?: string;
  DeviceId?: string;
  NextToken?: string;
  MaxResults?: number;
}
export interface MobileDeviceAccessOverride {
  UserId?: string;
  DeviceId?: string;
  Effect?: MobileDeviceAccessRuleEffect;
  Description?: string;
  DateCreated?: Date;
  DateModified?: Date;
}
export interface ListMobileDeviceAccessOverridesResponse {
  Overrides?: MobileDeviceAccessOverride[];
  NextToken?: string;
}
export interface ListMobileDeviceAccessRulesRequest {
  OrganizationId: string | undefined;
}
export interface MobileDeviceAccessRule {
  MobileDeviceAccessRuleId?: string;
  Name?: string;
  Description?: string;
  Effect?: MobileDeviceAccessRuleEffect;
  DeviceTypes?: string[];
  NotDeviceTypes?: string[];
  DeviceModels?: string[];
  NotDeviceModels?: string[];
  DeviceOperatingSystems?: string[];
  NotDeviceOperatingSystems?: string[];
  DeviceUserAgents?: string[];
  NotDeviceUserAgents?: string[];
  DateCreated?: Date;
  DateModified?: Date;
}
export interface ListMobileDeviceAccessRulesResponse {
  Rules?: MobileDeviceAccessRule[];
}
export interface ListOrganizationsRequest {
  NextToken?: string;
  MaxResults?: number;
}
export interface OrganizationSummary {
  OrganizationId?: string;
  Alias?: string;
  DefaultMailDomain?: string;
  ErrorMessage?: string;
  State?: string;
}
export interface ListOrganizationsResponse {
  OrganizationSummaries?: OrganizationSummary[];
  NextToken?: string;
}
export interface ListResourceDelegatesRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ListResourceDelegatesResponse {
  Delegates?: Delegate[];
  NextToken?: string;
}
export interface ListResourcesFilters {
  NamePrefix?: string;
  PrimaryEmailPrefix?: string;
  State?: EntityState;
}
export interface ListResourcesRequest {
  OrganizationId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
  Filters?: ListResourcesFilters;
}
export interface Resource {
  Id?: string;
  Email?: string;
  Name?: string;
  Type?: ResourceType;
  State?: EntityState;
  EnabledDate?: Date;
  DisabledDate?: Date;
  Description?: string;
}
export interface ListResourcesResponse {
  Resources?: Resource[];
  NextToken?: string;
}
export interface ListTagsForResourceRequest {
  ResourceARN: string | undefined;
}
export interface Tag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface ListTagsForResourceResponse {
  Tags?: Tag[];
}
export interface ListUsersFilters {
  UsernamePrefix?: string;
  DisplayNamePrefix?: string;
  PrimaryEmailPrefix?: string;
  State?: EntityState;
}
export interface ListUsersRequest {
  OrganizationId: string | undefined;
  NextToken?: string;
  MaxResults?: number;
  Filters?: ListUsersFilters;
}
export interface User {
  Id?: string;
  Email?: string;
  Name?: string;
  DisplayName?: string;
  State?: EntityState;
  UserRole?: UserRole;
  EnabledDate?: Date;
  DisabledDate?: Date;
}
export interface ListUsersResponse {
  Users?: User[];
  NextToken?: string;
}
export interface PutAccessControlRuleRequest {
  Name: string | undefined;
  Effect: AccessControlRuleEffect | undefined;
  Description: string | undefined;
  IpRanges?: string[];
  NotIpRanges?: string[];
  Actions?: string[];
  NotActions?: string[];
  UserIds?: string[];
  NotUserIds?: string[];
  OrganizationId: string | undefined;
  ImpersonationRoleIds?: string[];
  NotImpersonationRoleIds?: string[];
}
export interface PutAccessControlRuleResponse {}
export interface PutEmailMonitoringConfigurationRequest {
  OrganizationId: string | undefined;
  RoleArn: string | undefined;
  LogGroupArn: string | undefined;
}
export interface PutEmailMonitoringConfigurationResponse {}
export interface PutInboundDmarcSettingsRequest {
  OrganizationId: string | undefined;
  Enforced: boolean | undefined;
}
export interface PutInboundDmarcSettingsResponse {}
export interface PutMailboxPermissionsRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  GranteeId: string | undefined;
  PermissionValues: PermissionType[] | undefined;
}
export interface PutMailboxPermissionsResponse {}
export interface PutMobileDeviceAccessOverrideRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  DeviceId: string | undefined;
  Effect: MobileDeviceAccessRuleEffect | undefined;
  Description?: string;
}
export interface PutMobileDeviceAccessOverrideResponse {}
export interface PutRetentionPolicyRequest {
  OrganizationId: string | undefined;
  Id?: string;
  Name: string | undefined;
  Description?: string;
  FolderConfigurations: FolderConfiguration[] | undefined;
}
export interface PutRetentionPolicyResponse {}
export interface RegisterMailDomainRequest {
  ClientToken?: string;
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface RegisterMailDomainResponse {}
export interface RegisterToWorkMailRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Email: string | undefined;
}
export interface RegisterToWorkMailResponse {}
export interface ResetPasswordRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  Password: string | undefined;
}
export interface ResetPasswordResponse {}
export interface StartMailboxExportJobRequest {
  ClientToken?: string;
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Description?: string;
  RoleArn: string | undefined;
  KmsKeyArn: string | undefined;
  S3BucketName: string | undefined;
  S3Prefix: string | undefined;
}
export interface StartMailboxExportJobResponse {
  JobId?: string;
}
export interface TagResourceRequest {
  ResourceARN: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagResourceResponse {}
export declare class TooManyTagsException extends __BaseException {
  readonly name: "TooManyTagsException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<TooManyTagsException, __BaseException>
  );
}
export interface TestAvailabilityConfigurationRequest {
  OrganizationId: string | undefined;
  DomainName?: string;
  EwsProvider?: EwsAvailabilityProvider;
  LambdaProvider?: LambdaAvailabilityProvider;
}
export interface TestAvailabilityConfigurationResponse {
  TestPassed?: boolean;
  FailureReason?: string;
}
export interface UntagResourceRequest {
  ResourceARN: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateAvailabilityConfigurationRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
  EwsProvider?: EwsAvailabilityProvider;
  LambdaProvider?: LambdaAvailabilityProvider;
}
export interface UpdateAvailabilityConfigurationResponse {}
export interface UpdateDefaultMailDomainRequest {
  OrganizationId: string | undefined;
  DomainName: string | undefined;
}
export interface UpdateDefaultMailDomainResponse {}
export interface UpdateGroupRequest {
  OrganizationId: string | undefined;
  GroupId: string | undefined;
  HiddenFromGlobalAddressList?: boolean;
}
export interface UpdateGroupResponse {}
export interface UpdateImpersonationRoleRequest {
  OrganizationId: string | undefined;
  ImpersonationRoleId: string | undefined;
  Name: string | undefined;
  Type: ImpersonationRoleType | undefined;
  Description?: string;
  Rules: ImpersonationRule[] | undefined;
}
export interface UpdateImpersonationRoleResponse {}
export interface UpdateMailboxQuotaRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  MailboxQuota: number | undefined;
}
export interface UpdateMailboxQuotaResponse {}
export interface UpdateMobileDeviceAccessRuleRequest {
  OrganizationId: string | undefined;
  MobileDeviceAccessRuleId: string | undefined;
  Name: string | undefined;
  Description?: string;
  Effect: MobileDeviceAccessRuleEffect | undefined;
  DeviceTypes?: string[];
  NotDeviceTypes?: string[];
  DeviceModels?: string[];
  NotDeviceModels?: string[];
  DeviceOperatingSystems?: string[];
  NotDeviceOperatingSystems?: string[];
  DeviceUserAgents?: string[];
  NotDeviceUserAgents?: string[];
}
export interface UpdateMobileDeviceAccessRuleResponse {}
export interface UpdatePrimaryEmailAddressRequest {
  OrganizationId: string | undefined;
  EntityId: string | undefined;
  Email: string | undefined;
}
export interface UpdatePrimaryEmailAddressResponse {}
export interface UpdateResourceRequest {
  OrganizationId: string | undefined;
  ResourceId: string | undefined;
  Name?: string;
  BookingOptions?: BookingOptions;
  Description?: string;
  Type?: ResourceType;
  HiddenFromGlobalAddressList?: boolean;
}
export interface UpdateResourceResponse {}
export interface UpdateUserRequest {
  OrganizationId: string | undefined;
  UserId: string | undefined;
  Role?: UserRole;
  DisplayName?: string;
  FirstName?: string;
  LastName?: string;
  HiddenFromGlobalAddressList?: boolean;
  Initials?: string;
  Telephone?: string;
  Street?: string;
  JobTitle?: string;
  City?: string;
  Company?: string;
  ZipCode?: string;
  Department?: string;
  Country?: string;
  Office?: string;
}
export interface UpdateUserResponse {}
export declare const EwsAvailabilityProviderFilterSensitiveLog: (
  obj: EwsAvailabilityProvider
) => any;
export declare const CreateAvailabilityConfigurationRequestFilterSensitiveLog: (
  obj: CreateAvailabilityConfigurationRequest
) => any;
export declare const CreateUserRequestFilterSensitiveLog: (
  obj: CreateUserRequest
) => any;
export declare const DescribeUserResponseFilterSensitiveLog: (
  obj: DescribeUserResponse
) => any;
export declare const ListUsersFiltersFilterSensitiveLog: (
  obj: ListUsersFilters
) => any;
export declare const ListUsersRequestFilterSensitiveLog: (
  obj: ListUsersRequest
) => any;
export declare const PutRetentionPolicyRequestFilterSensitiveLog: (
  obj: PutRetentionPolicyRequest
) => any;
export declare const ResetPasswordRequestFilterSensitiveLog: (
  obj: ResetPasswordRequest
) => any;
export declare const TestAvailabilityConfigurationRequestFilterSensitiveLog: (
  obj: TestAvailabilityConfigurationRequest
) => any;
export declare const UpdateAvailabilityConfigurationRequestFilterSensitiveLog: (
  obj: UpdateAvailabilityConfigurationRequest
) => any;
export declare const UpdateUserRequestFilterSensitiveLog: (
  obj: UpdateUserRequest
) => any;
